@@ -28,13 +28,13 @@ enum TestType {
 }
 
 // Test task.
-pub async fn get_index(user: &GooseUser) -> GooseTaskResult {
+pub async fn get_index(user: &mut GooseUser) -> GooseTaskResult {
     let _goose = user.get(INDEX_PATH).await?;
     Ok(())
 }
 
 // Test task.
-pub async fn get_about(user: &GooseUser) -> GooseTaskResult {
+pub async fn get_about(user: &mut GooseUser) -> GooseTaskResult {
     let _goose = user.get(ABOUT_PATH).await?;
     Ok(())
 }
@@ -157,7 +157,7 @@ fn get_tasks() -> GooseTaskSet {
 }
 
 // Helper to run all standalone tests.
-fn run_standalone_test(test_type: TestType) {
+async fn run_standalone_test(test_type: TestType) {
     // Start the mock server.
     let server = MockServer::start();
 
@@ -176,14 +176,15 @@ fn run_standalone_test(test_type: TestType) {
     let goose_metrics = common::run_load_test(
         common::build_load_test(configuration.clone(), &get_tasks(), None, None),
         None,
-    );
+    )
+    .await;
 
     // Confirm that the load test ran correctly.
     validate_one_taskset(&goose_metrics, &mock_endpoints, &configuration, test_type);
 }
 
 // Helper to run all standalone tests.
-fn run_gaggle_test(test_type: TestType) {
+async fn run_gaggle_test(test_type: TestType) {
     // Start the mock server.
     let server = MockServer::start();
 
@@ -193,11 +194,10 @@ fn run_gaggle_test(test_type: TestType) {
     // Each worker has the same identical configuration.
     let worker_configuration = common::build_configuration(&server, vec!["--worker"]);
 
-    // Build the load test for the Workers.
-    let goose_attack = common::build_load_test(worker_configuration, &get_tasks(), None, None);
-
     // Workers launched in own threads, store thread handles.
-    let worker_handles = common::launch_gaggle_workers(goose_attack, EXPECT_WORKERS);
+    let worker_handles = common::launch_gaggle_workers(EXPECT_WORKERS, || {
+        common::build_load_test(worker_configuration.clone(), &get_tasks(), None, None)
+    });
 
     // Build common configuration elements, adding Manager Gaggle flags.
     let manager_configuration = match test_type {
@@ -221,7 +221,7 @@ fn run_gaggle_test(test_type: TestType) {
         common::build_load_test(manager_configuration.clone(), &get_tasks(), None, None);
 
     // Run the Goose Attack.
-    let goose_metrics = common::run_load_test(manager_goose_attack, Some(worker_handles));
+    let goose_metrics = common::run_load_test(manager_goose_attack, Some(worker_handles)).await;
 
     // Confirm that the load test ran correctly.
     validate_one_taskset(
@@ -232,24 +232,24 @@ fn run_gaggle_test(test_type: TestType) {
     );
 }
 
-#[test]
+#[tokio::test]
 // Test a single task set with multiple weighted tasks.
-fn test_one_taskset() {
-    run_standalone_test(TestType::NoResetMetrics);
+async fn test_one_taskset() {
+    run_standalone_test(TestType::NoResetMetrics).await;
 }
 
-#[test]
+#[tokio::test(flavor = "multi_thread", worker_threads = 8)]
 #[cfg_attr(not(feature = "gaggle"), ignore)]
 #[serial]
 // Test a single task set with multiple weighted tasks, in Gaggle mode.
-fn test_one_taskset_gaggle() {
-    run_gaggle_test(TestType::NoResetMetrics);
+async fn test_one_taskset_gaggle() {
+    run_gaggle_test(TestType::NoResetMetrics).await;
 }
 
-#[test]
+#[tokio::test]
 // Test a single task set with multiple weighted tasks, enable --no-reset-metrics.
-fn test_one_taskset_reset_metrics() {
-    run_standalone_test(TestType::ResetMetrics);
+async fn test_one_taskset_reset_metrics() {
+    run_standalone_test(TestType::ResetMetrics).await;
 }
 
 /* @TODO: @FIXME: Goose is not resetting metrics when running in Gaggle mode.
